@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -26,6 +26,35 @@ class TiwClient(AbstractClient):
     _service = 'tiw'
 
 
+    def CreateSnapshotTask(self, request):
+        """创建白板板书生成任务, 在任务结束后，如果提供了回调地址，将通过回调地址通知板书生成结果
+
+        :param request: Request instance for CreateSnapshotTask.
+        :type request: :class:`tencentcloud.tiw.v20190919.models.CreateSnapshotTaskRequest`
+        :rtype: :class:`tencentcloud.tiw.v20190919.models.CreateSnapshotTaskResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateSnapshotTask", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateSnapshotTaskResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateTranscode(self, request):
         """创建一个文档转码任务
 
@@ -36,7 +65,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateTranscode", params)
+            headers = request.headers
+            body = self.call("CreateTranscode", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateTranscodeResponse()
@@ -64,7 +94,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateVideoGenerationTask", params)
+            headers = request.headers
+            body = self.call("CreateVideoGenerationTask", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateVideoGenerationTaskResponse()
@@ -92,7 +123,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeOnlineRecord", params)
+            headers = request.headers
+            body = self.call("DescribeOnlineRecord", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeOnlineRecordResponse()
@@ -120,7 +152,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeOnlineRecordCallback", params)
+            headers = request.headers
+            body = self.call("DescribeOnlineRecordCallback", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeOnlineRecordCallbackResponse()
@@ -138,6 +171,95 @@ class TiwClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeQualityMetrics(self, request):
+        """查询互动白板质量数据
+
+        :param request: Request instance for DescribeQualityMetrics.
+        :type request: :class:`tencentcloud.tiw.v20190919.models.DescribeQualityMetricsRequest`
+        :rtype: :class:`tencentcloud.tiw.v20190919.models.DescribeQualityMetricsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeQualityMetrics", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeQualityMetricsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeSnapshotTask(self, request):
+        """获取指定白板板书生成任务信息
+
+        :param request: Request instance for DescribeSnapshotTask.
+        :type request: :class:`tencentcloud.tiw.v20190919.models.DescribeSnapshotTaskRequest`
+        :rtype: :class:`tencentcloud.tiw.v20190919.models.DescribeSnapshotTaskResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeSnapshotTask", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeSnapshotTaskResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeTIWDailyUsage(self, request):
+        """查询互动白板天维度计费用量。
+        1. 单次查询统计区间最多不能超过31天。
+        2. 由于统计延迟等原因，暂时不支持查询当天数据，建议在次日上午7点以后再来查询前一天的用量，例如在10月27日上午7点后，再来查询到10月26日整天的用量
+
+        :param request: Request instance for DescribeTIWDailyUsage.
+        :type request: :class:`tencentcloud.tiw.v20190919.models.DescribeTIWDailyUsageRequest`
+        :rtype: :class:`tencentcloud.tiw.v20190919.models.DescribeTIWDailyUsageResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeTIWDailyUsage", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeTIWDailyUsageResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeTranscode(self, request):
         """查询文档转码任务的执行进度与转码结果
 
@@ -148,7 +270,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTranscode", params)
+            headers = request.headers
+            body = self.call("DescribeTranscode", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTranscodeResponse()
@@ -176,7 +299,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTranscodeCallback", params)
+            headers = request.headers
+            body = self.call("DescribeTranscodeCallback", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTranscodeCallbackResponse()
@@ -204,7 +328,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeVideoGenerationTask", params)
+            headers = request.headers
+            body = self.call("DescribeVideoGenerationTask", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeVideoGenerationTaskResponse()
@@ -232,7 +357,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeVideoGenerationTaskCallback", params)
+            headers = request.headers
+            body = self.call("DescribeVideoGenerationTaskCallback", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeVideoGenerationTaskCallbackResponse()
@@ -260,7 +386,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeWhiteboardPush", params)
+            headers = request.headers
+            body = self.call("DescribeWhiteboardPush", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeWhiteboardPushResponse()
@@ -288,7 +415,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeWhiteboardPushCallback", params)
+            headers = request.headers
+            body = self.call("DescribeWhiteboardPushCallback", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeWhiteboardPushCallbackResponse()
@@ -316,7 +444,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("PauseOnlineRecord", params)
+            headers = request.headers
+            body = self.call("PauseOnlineRecord", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.PauseOnlineRecordResponse()
@@ -344,7 +473,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ResumeOnlineRecord", params)
+            headers = request.headers
+            body = self.call("ResumeOnlineRecord", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ResumeOnlineRecordResponse()
@@ -372,7 +502,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SetOnlineRecordCallback", params)
+            headers = request.headers
+            body = self.call("SetOnlineRecordCallback", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SetOnlineRecordCallbackResponse()
@@ -400,7 +531,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SetOnlineRecordCallbackKey", params)
+            headers = request.headers
+            body = self.call("SetOnlineRecordCallbackKey", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SetOnlineRecordCallbackKeyResponse()
@@ -428,7 +560,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SetTranscodeCallback", params)
+            headers = request.headers
+            body = self.call("SetTranscodeCallback", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SetTranscodeCallbackResponse()
@@ -456,7 +589,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SetTranscodeCallbackKey", params)
+            headers = request.headers
+            body = self.call("SetTranscodeCallbackKey", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SetTranscodeCallbackKeyResponse()
@@ -484,7 +618,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SetVideoGenerationTaskCallback", params)
+            headers = request.headers
+            body = self.call("SetVideoGenerationTaskCallback", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SetVideoGenerationTaskCallbackResponse()
@@ -512,7 +647,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SetVideoGenerationTaskCallbackKey", params)
+            headers = request.headers
+            body = self.call("SetVideoGenerationTaskCallbackKey", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SetVideoGenerationTaskCallbackKeyResponse()
@@ -540,7 +676,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SetWhiteboardPushCallback", params)
+            headers = request.headers
+            body = self.call("SetWhiteboardPushCallback", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SetWhiteboardPushCallbackResponse()
@@ -568,7 +705,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SetWhiteboardPushCallbackKey", params)
+            headers = request.headers
+            body = self.call("SetWhiteboardPushCallbackKey", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SetWhiteboardPushCallbackKeyResponse()
@@ -596,7 +734,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("StartOnlineRecord", params)
+            headers = request.headers
+            body = self.call("StartOnlineRecord", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.StartOnlineRecordResponse()
@@ -624,7 +763,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("StartWhiteboardPush", params)
+            headers = request.headers
+            body = self.call("StartWhiteboardPush", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.StartWhiteboardPushResponse()
@@ -652,7 +792,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("StopOnlineRecord", params)
+            headers = request.headers
+            body = self.call("StopOnlineRecord", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.StopOnlineRecordResponse()
@@ -680,7 +821,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("StopWhiteboardPush", params)
+            headers = request.headers
+            body = self.call("StopWhiteboardPush", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.StopWhiteboardPushResponse()
